import system from '@/utils/system'
import toast from '@/utils/toast'

const MAX_SNAP_SHOT_LENGTH = 3

// 设置画布默认数据 https://github.com/woai3c/visual-drag-demo/issues/92
let defaultComponentData: any[] = []

function getDefaultComponentData() : any[] {
    return defaultComponentData
}

export function setDefaultComponentData(data = []) {
    defaultComponentData = data
}

export default {
    state: {
        snapshotData: [], // 编辑器快照数据
        snapshotIndex: -1 // 快照索引
    },
    actions: {
        undo(state) {
            if (state.snapshotIndex >= 1) {
                state.snapshotIndex--
                const componentData = system.deepCopy(state.snapshotData[state.snapshotIndex]) || getDefaultComponentData()
                if (state.curComponent) {
                    // 如果当前组件不在 componentData 中，则置空
                    const needClean = !componentData.find(
                        (component) => state.curComponent.id === component.id
                    )

                    if (needClean) {
                        store.commit('printTemplateModule/setCurComponent', {
                            component: null,
                            index: null
                        })
                    }
                }
                store.commit('printTemplateModule/setComponentData', componentData)
            } else {
                toast('不能再撤销了')
            }
        },

        redo(state) {
            if (state.snapshotIndex < state.snapshotData.length - 1) {
                state.snapshotIndex++
                store.commit(
                    'printTemplateModule/setComponentData',
                    system.deepCopy(state.snapshotData[state.snapshotIndex])
                )
            } else {
                toast('不能再恢复了')
            }
        },

        recordSnapshot() {
            // 添加新的快照
            this.snapshotData[++this.snapshotIndex] = system.deepCopy(this.componentData)
            // 在 undo 过程中，添加新的快照时，要将它后面的快照清理掉
            if (this.snapshotIndex < this.snapshotData.length - 1) {
                this.snapshotData = this.snapshotData.slice(0, this.snapshotIndex + 1)
            }
            if (this.snapshotData.length > MAX_SNAP_SHOT_LENGTH) {
                // 只保留最近50次操作
                this.snapshotData = this.snapshotData.slice(1)
                this.snapshotIndex--
            }
        }
    }
}
