/** 所有变量类型 */
enum typeEnum {
    string = 'string',
    number = 'number',
    object = 'object',
    array = 'array',
    function = 'function',
    null = 'null',
    boolean = 'boolean',
    symbol = 'symbol',
    json = 'json',
    math = 'math',
    regexp = 'regexp',
    date = 'date',
    undefined = 'undefined',
    nan = 'nan',
    reactNode = 'react_node',
}

/**
 * 判断对象类型
 * @param object 对象
 */
const variableTypeOf = (object?: any): typeEnum => {
    const typeStr = Object.prototype.toString.call(object);
    let typeName: typeEnum;
    switch (`${typeStr}`.toLowerCase()) {
        case '[object string]':
            typeName = typeEnum.string;
            break;
        case '[object number]':
            if (Number.isNaN(object)) {
                return typeEnum.nan;
            }
            typeName = typeEnum.number;
            break;
        case '[object object]':
            if (object.$$typeof && object.props) {
                const type = variableTypeOf(object.$$typeof);
                if (type === typeEnum.symbol || type === typeEnum.reactNode) {
                    return typeEnum.reactNode;
                }
            }
            typeName = typeEnum.object;
            break;
        case '[object array]':
            typeName = typeEnum.array;
            break;
        case '[object function]':
            typeName = typeEnum.function;
            break;
        case '[object null]':
            typeName = typeEnum.null;
            break;
        case '[object boolean]':
            typeName = typeEnum.boolean;
            break;
        case '[object date]':
            typeName = typeEnum.date;
            break;
        // 不常用
        case '[object symbol]':
            typeName = typeEnum.symbol;
            break;
        case '[object json]':
            typeName = typeEnum.json;
            break;
        case '[object math]':
            typeName = typeEnum.math;
            break;
        case '[object regexp]':
            typeName = typeEnum.regexp;
            break;
        // 貌似不会走的分支
        case '[object undefined]':
            typeName = typeEnum.undefined;
            break;
        // 无法识别
        default:
            if (object === undefined) {
                return typeEnum.undefined;
            }
            console.log('varTypeOf -> ', object, ' | -> ', typeStr, ' | ', `${typeStr}`.toLowerCase());
            typeName = typeEnum.object;
    }
    return typeName;
};

export default {
    typeEnum,
    variableTypeOf,
};
