import {defineConfig} from 'vite'
import path from "path";
import vue from '@vitejs/plugin-vue'
import AutoImport from 'unplugin-auto-import/vite'
import Components from 'unplugin-vue-components/vite'
import {ElementPlusResolver} from 'unplugin-vue-components/resolvers'

// https://vitejs.dev/config/
export default defineConfig({
    plugins: [
        vue(),
        AutoImport({
            resolvers: [ElementPlusResolver()],
        }),
        Components({
            resolvers: [ElementPlusResolver()],
        }),],
    resolve: {
        alias: {
            // @代替src
            "@": path.resolve("./src"),
            // #代替types
            "#": path.resolve("./types"),
        },
    },
    css: {
        preprocessorOptions: {
            less: {
                modifyVars: {
                    hack: `true; @import (reference) "${path.resolve("src/assets/style/main.less")}";`,
                },
                javascriptEnabled: true,
            },
        },
    },
    server: {
        host: true,
        port: 5170,
        proxy: {
            '^/wms_api/print/.*': {
                target: 'http://localhost:9085',
                changeOrigin: false,
            },
            '^/wms_api/.*': {
                target: 'http://localhost:9085',
                changeOrigin: false,
            },
        }
    }
})
